@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Type::Params::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Params::VERSION   = '2.007_002';
+	$Type::Params::VERSION   = '2.007_003';
 }
 
 $Type::Params::VERSION =~ tr/_//d;
@@ -33,7 +33,7 @@ our @EXPORT_OK = qw(
 	multisig
 	Invocant ArgsObject
 	wrap_subs wrap_methods
-	signature signature_for
+	signature signature_for signature_for_func signature_for_method
 );
 
 our %EXPORT_TAGS = (
@@ -41,9 +41,10 @@ our %EXPORT_TAGS = (
 	wrap     => [ qw( wrap_subs wrap_methods ) ],
 	sigs     => [ qw( signature signature_for ) ],
 	validate => [ qw( validate validate_named ) ],
+	sigplus  => [ qw( signature signature_for signature_for_func signature_for_method ) ],
 	
-	v1       => [ qw( compile compile_named ) ],   # Old default
-	v2       => [ qw( signature signature_for ) ], # New recommendation
+	v1       => [ qw( compile compile_named ) ],      # Old default
+	v2       => [ qw( signature signature_for ) ],    # New recommendation
 );
 
 {
@@ -169,6 +170,28 @@ sub signature_for {
 	return $sig;
 }
 
+sub signature_for_func {
+	if ( not @_ % 2 ) {
+		require Error::TypeTiny;
+		Error::TypeTiny::croak( "Expected odd-sized list of arguments; did you forget the function name?" );
+	}
+	my ( $function, %opts ) = @_;
+	my $N = !!$opts{named};
+	@_ = ( $function, method => 0, allow_dash => $N, list_to_named => $N, %opts );
+	goto \&signature_for;
+}
+
+sub signature_for_method {
+	if ( not @_ % 2 ) {
+		require Error::TypeTiny;
+		Error::TypeTiny::croak( "Expected odd-sized list of arguments; did you forget the function name?" );
+	}
+	my ( $function, %opts ) = @_;
+	my $N = !!$opts{named};
+	@_ = ( $function, method => 1, allow_dash => $N, list_to_named => $N, %opts );
+	goto \&signature_for;
+}
+
 sub compile {
 	my @args = @_;
 	@_ = ( positional => \@args );
@@ -394,6 +417,14 @@ Or by requesting functions by name:
 
  use Type::Params qw( signature signature_for );
 
+Two optional shortcuts can be exported:
+
+ use Type::Params qw( signature_for_func signature_for_method );
+
+Or:
+
+ use Type::Params -sigplus;
+
 =head2 C<< signature( %spec ) >>
 
 The C<signature> function takes a specification for your function's
@@ -588,6 +619,79 @@ in.)
    return $num1 + $num2;
  }
 
+=head4 C<< list_to_named >> B<< Bool >>
+
+For a function that accepts named parameters, allows them to alternatively
+be supplied as a list in a hopefully do-what-you-mean manner.
+
+ sub add_numbers {
+   state $sig = signature(
+     named         => [ num1 => Num, num2 => Num ],
+     list_to_named => !!1,
+   );
+   my ( $arg ) = $sig->( @_ );
+   
+   return $arg->num1 + $arg->num2;
+ }
+ 
+ say add_numbers( num1 => 5, num2 => 10 );         # says 15
+ say add_numbers( { num1 => 5, num2 => 10 } );     # also says 15
+ say add_numbers( 5, num2 => 10 );                 # says 15 yet again
+ say add_numbers( 5, { num2 => 10 } );             # guess what? says 15
+ say add_numbers( 10, num1 => 5 );                 # 14... just kidding... 15
+ say add_numbers( 10, { num1 => 5 } );             # another 15
+ say add_numbers( 5, 10 );                         # surprise, it says 15
+ 
+ say add_numbers( { num1 => 5 }, 10 );             # error! positional at end
+ say add_numbers( 5, 10, { num1 => 3 } );          # error! duplicate argument
+
+Where a hash or hashref of named parameters are expected, any parameter
+which doesn't look like it fits that pattern will be treated as a sneaky
+positional parameter, and will be tried the first time a named parameter
+is "missing".
+
+This feature is normally only applied to required parameters. It can be
+manually controlled on a per-parameter basis using the C<in_list> option.
+
+Type::Params attempts to be intelligent at figuring out what order
+the sneaky positional parameters were given in.
+
+ sub add_to_ref {
+   state $sig = signature(
+     named         => [ ref => ScalarRef[Num], add => Num ],
+     list_to_named => !!1,
+   );
+   my ( $arg ) = $sig->( @_ );
+   
+   $arg->ref->$* += $arg->num;
+ }
+ 
+ my $sum = 0;
+ add_to_ref( ref => \$sum, add => 1 );
+ add_to_ref( \$sum, add => 2 );
+ add_to_ref( \$sum, 3 );
+ add_to_ref( 4, \$sum );
+ add_to_ref( 5, sum => \$sum );
+ add_to_ref( add => 5, sum => \$sum );
+ say $sum; # 21
+
+This approach is somewhat slower, but has the potential for very
+do-what-I-mean functions.
+
+Note that C<list_to_named> and C<named_to_list> can both be used in
+the same signature as their meanings are not contradictory.
+
+ sub add_to_ref {
+   state $sig = signature(
+     named         => [ ref => ScalarRef[Num], add => Num ],
+     list_to_named => !!1,
+     named_to_list => !!1,
+   );
+   my ( $ref, $num ) = $sig->( @_ );
+   
+   $ref->$* += $arg->num;
+ }
+
 =head4 C<< head >> B<< Int|ArrayRef >>
 
 C<head> provides an additional list of non-optional, positional parameters
@@ -1085,6 +1189,26 @@ options are considered I<advisorary> and I<for documentation> and are
 not actually checked! However, the C<signature_for> keyword, which wraps
 your entire sub, I<is> able to check them.
 
+=head4 C<< allow_dash >> B<Bool>
+
+For any "word-like" named parameters or aliases, automatically creates an
+alias with a leading hyphen.
+
+ sub withdraw_funds {
+   state $sig = signature(
+     named      => [ amount => Num, account => Str ],
+     allow_dash => 1,
+   );
+   ...;
+ }
+ 
+ withdraw_funds(  amount => 11.99,  account => 'ABC123' );
+ withdraw_funds( -amount => 11.99,  account => 'ABC123' );
+ withdraw_funds(  amount => 11.99, -account => 'ABC123' );
+ withdraw_funds( -amount => 11.99, -account => 'ABC123' );
+
+Has no effect on names that are not word-like.
+
 =head3 Parameter Options
 
 In the parameter lists for the C<positional> and C<named> signature
@@ -1428,6 +1552,15 @@ name.
 
 Ignored by signatures with positional parameters.
 
+=head4 C<< in_list >> B<Bool>
+
+In conjunction with C<list_to_named>, determines if this parameter can
+be provided as part of the list of "sneaky" positional parameters.
+If C<list_to_named> isn't being used, C<in_list> is ignored.
+
+Defaults to false if the parameter is optional or has a default.
+Defaults to true if the parameter is required.
+
 =head4 C<< strictness >> B<Bool|Str>
 
 Overrides the signature option C<strictness> on a per-parameter basis.
@@ -1536,6 +1669,61 @@ Or when used with multiple functions:
 This is a blessed L<Type::Params::Signature> object which provides some
 introspection possibilities.
 
+=head2 C<< signature_for_func $function_name => ( %spec ) >>
+
+Like C<signature_for> but for signatures with named parameters
+will default C<list_to_named> and C<allow_dash> to true.
+
+ signature_for_func add_to_ref => (
+   named         => [ ref => ScalarRef[Num], add => Num ],
+   named_to_list => 1,
+ );
+ 
+ sub add_to_ref ( $ref, $add ) {
+   $ref->$* += $add;
+ }
+ 
+ my $sum = 0;
+ add_to_ref( ref => \$sum, add => 1 );
+ add_to_ref( \$sum, 2 );
+ add_to_ref( 3, \$sum );
+ add_to_ref( 4, { -ref => \$sum } );
+ say $sum; # 10
+
+The exact behaviour of C<signature_for_func> is unstable and may change
+in future versions of Type::Params.
+
+=head2 C<< signature_for_method $function_name => ( %spec ) >>
+
+Like C<signature_for_func> but will default C<method> to true.
+
+ package Calculator {
+   use Types::Standard qw( Num ScalarRef );
+   use Type::Params qw( signature_for_method );
+   
+   ...;
+   
+   signature_for_method add_to_ref => (
+     named         => [ ref => ScalarRef[Num], add => Num ],
+     named_to_list => 1,
+   );
+   
+   sub add_to_ref ( $self, $ref, $add ) {
+     $ref->$* += $add;
+   }
+ }
+ 
+ my $calc = Calculator->new;
+ my $sum = 0;
+ $calc->add_to_ref( ref => \$sum, add => 1 );
+ $calc->add_to_ref( \$sum, 2 );
+ $calc->add_to_ref( 3, \$sum );
+ $calc->add_to_ref( 4, { -ref => \$sum } );
+ say $sum; # 10
+
+The exact behaviour of C<signature_for_method> is unstable and may change
+in future versions of Type::Params.
+
 =head1 LEGACY API
 
 The following functions were the API prior to Type::Params v2. They are
@@ -1730,7 +1918,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2024 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2025 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
