@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Signature::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Signature::VERSION    = '2.007_002';
+	$Type::Params::Signature::VERSION    = '2.007_003';
 }
 
 $Type::Params::Signature::VERSION =~ tr/_//d;
@@ -295,10 +295,12 @@ sub on_die        { $_[0]{on_die} }          sub has_on_die        { exists $_[0
 sub strictness    { $_[0]{strictness} }      sub has_strictness    { exists $_[0]{strictness} }
 sub goto_next     { $_[0]{goto_next} }
 sub is_named      { $_[0]{is_named} }
+sub allow_dash    { $_[0]{allow_dash} }
 sub bless         { $_[0]{bless} }
 sub class         { $_[0]{class} }
 sub constructor   { $_[0]{constructor} }
 sub named_to_list { $_[0]{named_to_list} }
+sub list_to_named { $_[0]{list_to_named} }
 sub oo_trace      { $_[0]{oo_trace} }
 sub returns_scalar{ $_[0]{returns_scalar} }  sub has_returns_scalar{ defined $_[0]{returns_scalar} }
 sub returns_list  { $_[0]{returns_list} }    sub has_returns_list  { defined $_[0]{returns_list} }
@@ -443,7 +445,22 @@ sub _coderef_check_count {
 	#   your_func( %opts, y => 2 ); # override y
 	#
 
-	if ( $is_named ) {
+	if ( $is_named and $self->list_to_named ) {
+		require List::Util;
+		my $args_if_hashref  = $headtail + 1;
+		my $min_args_if_list = $headtail + List::Util::sum0( map { $_->optional ? 0 : $_->in_list ? 1 : 2 } @{ $self->parameters } );
+		$self->{min_args} = List::Util::min( $args_if_hashref, $min_args_if_list );
+		
+		$coderef->add_line( $strictness_test . sprintf(
+			"\@_ >= %d\n\tor %s;",
+			$self->{min_args},
+			$self->_make_count_fail(
+				coderef   => $coderef,
+				got       => 'scalar( @_ )',
+			),
+		) );
+	}
+	elsif ( $is_named ) {
 		my $args_if_hashref  = $headtail + 1;
 		my $hashref_index    = @{ $self->head || [] };
 		my $arity_if_hash    = $headtail % 2;
@@ -594,12 +611,27 @@ sub _coderef_parameters {
 	my ( $self, $coderef ) = ( shift, @_ );
 
 	if ( $self->is_named ) {
+		
+		if ( $self->list_to_named ) {
+			require Type::Tiny::Enum;
+			my $Keys = Type::Tiny::Enum->new( values => [ map { $_->name, $_->_all_aliases($self) } @{ $self->parameters } ] );
+			$coderef->addf( 'my @positional;' );
+			$coderef->addf( '{' );
+			$coderef->increase_indent;
+			$coderef->addf( 'last if ( @_ == 0 );' );
+			$coderef->addf( 'last if ( @_ == 1 and %s );', HashRef->inline_check( '$_[0]' ) );
+			$coderef->addf( 'last if ( @_ %% 2 == 0 and %s );', $Keys->inline_check( '$_[0]' ) );
+			$coderef->addf( 'push @positional, shift @_;' );
+			$coderef->addf( 'redo;' );
+			$coderef->decrease_indent;
+			$coderef->addf( '}' );
+			$coderef->add_gap;
+		}
 
 		$coderef->add_line( sprintf(
 			'%%in = ( @_ == 1 and %s ) ? %%{ $_[0] } : @_;',
 			HashRef->inline_check( '$_[0]' ),
 		) );
-
 		$coderef->add_gap;
 
 		for my $parameter ( @{ $self->parameters } ) {
@@ -615,6 +647,16 @@ sub _coderef_parameters {
 				type        => 'named_arg',
 			);
 		}
+		
+		if ( $self->list_to_named ) {
+			$coderef->add_line( sprintf(
+				'@positional and %s;',
+				$self->_make_general_fail(
+					coderef  => $coderef,
+					message  => q{'Superfluous positional arguments'},
+				),
+			) );
+		}
 	}
 	else {
 		my $can_shortcut = $self->can_shortcut;
@@ -1157,6 +1199,8 @@ of this module is to build it for you!
 
 =item C<< is_named >> B<Bool>
 
+=item C<< allow_dash >> B<Bool>
+
 =item C<< bless >> B<Bool|ClassName>
 
 =item C<< class >> B<ClassName>
@@ -1173,6 +1217,8 @@ on C<parameters>
 
 Can be coerced from a bool based on C<parameters>.
 
+=item C<< list_to_named >> B<< Bool >>
+
 =item C<< oo_trace >> B<Bool>
 
 Defaults to true. Indicates whether blessed C<< $arg >> hashrefs created by
@@ -1308,7 +1354,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2023-2024 by Toby Inkster.
+This software is copyright (c) 2023-2025 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
